@@ -14,8 +14,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef STREAMSREQUEST_H
-#define STREAMSREQUEST_H
+#ifndef QYOUTUBE_STREAMSREQUEST_H
+#define QYOUTUBE_STREAMSREQUEST_H
 
 #include "request.h"
 
@@ -44,4 +44,4 @@ private:
 
 }
 
-#endif // STREAMSREQUEST_H
+#endif // QYOUTUBE_STREAMSREQUEST_H
